Module queue

Module queue 

Work queue support for JetStream.

This module provides a convenient interface for creating and using work queues with JetStream, including support for interest-based consumers.

Structs

InterestQueue
A typed queue with interest-based retention and configurable codec.
InterestQueueBuilder
Builder for interest-based queues.
StreamingWorkQueue
A work queue that implements Stream for continuous message processing.
WorkQueue
A typed work queue backed by JetStream with configurable codec.
WorkQueueBuilder
Builder for work queues.
WorkQueueSink
A sink for pushing messages to a work queue.

Type Aliases

QueueMessage
A message from a work queue or interest queue.