pub struct WorkQueueSink<T, C: CodecType> { /* private fields */ }Expand description
A sink for pushing messages to a work queue.
Implementations
Sourceimpl<T: Serialize, C: CodecType> WorkQueueSink<T, C>
impl<T: Serialize, C: CodecType> WorkQueueSink<T, C>
Sourcepub async fn publish(&self, message: &T) -> Result<u64>
pub async fn publish(&self, message: &T) -> Result<u64>
Publish a message directly with error handling.
Unlike the Sink implementation, this method returns any publish errors
and waits for JetStream acknowledgment.
Example
use intercom::{Client, MsgPackCodec, WorkQueue};
use serde::{Deserialize, Serialize};
#[derive(Serialize, Deserialize)]
struct Job { id: u64 }
let client = Client::<MsgPackCodec>::connect("nats://localhost:4222").await?;
let jetstream = client.jetstream();
let queue = WorkQueue::<Job, MsgPackCodec>::builder(&jetstream, "jobs").create().await?;
let sink = queue.sink();
// Direct publish with acknowledgment
let seq = sink.publish(&Job { id: 1 }).await?;
println!("Published at sequence: {}", seq);Trait Implementations
Sourceimpl<T, C: CodecType> Clone for WorkQueueSink<T, C>
impl<T, C: CodecType> Clone for WorkQueueSink<T, C>
Sourceimpl<T: Serialize, C: CodecType> Sink<T> for WorkQueueSink<T, C>
impl<T: Serialize, C: CodecType> Sink<T> for WorkQueueSink<T, C>
Sourcefn poll_ready(self: Pin<&mut Self>, _cx: &mut Context<'_>) -> Poll<Result<()>>
fn poll_ready(self: Pin<&mut Self>, _cx: &mut Context<'_>) -> Poll<Result<()>>
Attempts to prepare the
Sink to receive a value. Read moreSourcefn start_send(self: Pin<&mut Self>, item: T) -> Result<()>
fn start_send(self: Pin<&mut Self>, item: T) -> Result<()>
Begin the process of sending a value to the sink.
Each call to this function must be preceded by a successful call to
poll_ready which returned Poll::Ready(Ok(())). Read moreAuto Trait Implementations
impl<T, C> Freeze for WorkQueueSink<T, C>
impl<T, C> !RefUnwindSafe for WorkQueueSink<T, C>
impl<T, C> Send for WorkQueueSink<T, C>where
T: Send,
impl<T, C> Sync for WorkQueueSink<T, C>where
T: Sync,
impl<T, C> Unpin for WorkQueueSink<T, C>
impl<T, C> !UnwindSafe for WorkQueueSink<T, C>